# Auto-generated __init__.py
from . import expr
from . import annotations_pb2, annotations_pb2_grpc, client_pb2, client_pb2_grpc, field_behavior_pb2, field_behavior_pb2_grpc, field_info_pb2, field_info_pb2_grpc, http_pb2, http_pb2_grpc, httpbody_pb2, httpbody_pb2_grpc, launch_stage_pb2, launch_stage_pb2_grpc, resource_pb2, resource_pb2_grpc, visibility_pb2, visibility_pb2_grpc

__all__ = ["annotations_pb2", "annotations_pb2_grpc", "client_pb2", "client_pb2_grpc", "expr", "field_behavior_pb2", "field_behavior_pb2_grpc", "field_info_pb2", "field_info_pb2_grpc", "http_pb2", "http_pb2_grpc", "httpbody_pb2", "httpbody_pb2_grpc", "launch_stage_pb2", "launch_stage_pb2_grpc", "resource_pb2", "resource_pb2_grpc", "visibility_pb2", "visibility_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth/v2/auth_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "auth/v2/auth_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1a\x61uth/v2/auth_service.proto\x12\x07\x61uth.v2\x1a\x13\x61uth/v2/token.proto\x1a\x16\x63ommon/v2/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x12user/v2/user.proto"@\n\x0cLoginRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password"\x8e\x01\n\rLoginResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12(\n\x05token\x18\x02 \x01(\x0b\x32\x12.auth.v2.AuthTokenR\x05token\x12(\n\x04user\x18\x03 \x01(\x0b\x32\x14.user.v2.UserProfileR\x04user":\n\x13RefreshTokenRequest\x12#\n\rrefresh_token\x18\x01 \x01(\tR\x0crefreshToken"k\n\x14RefreshTokenResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12(\n\x05token\x18\x02 \x01(\x0b\x32\x12.auth.v2.AuthTokenR\x05token";\n\x0eLogoutResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status2\xd3\x01\n\x0b\x41uthService\x12\x38\n\x05Login\x12\x15.auth.v2.LoginRequest\x1a\x16.auth.v2.LoginResponse"\x00\x12M\n\x0cRefreshToken\x12\x1c.auth.v2.RefreshTokenRequest\x1a\x1d.auth.v2.RefreshTokenResponse"\x00\x12;\n\x06Logout\x12\x16.google.protobuf.Empty\x1a\x17.auth.v2.LogoutResponse"\x00\x42\x98\x01\n\x0b\x63om.auth.v2B\x10\x41uthServiceProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\xa2\x02\x03\x41XX\xaa\x02\x07\x41uth.V2\xca\x02\x07\x41uth\\V2\xe2\x02\x13\x41uth\\V2\\GPBMetadata\xea\x02\x08\x41uth::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "auth.v2.auth_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\013com.auth.v2B\020AuthServiceProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\242\002\003AXX\252\002\007Auth.V2\312\002\007Auth\\V2\342\002\023Auth\\V2\\GPBMetadata\352\002\010Auth::V2"
    _globals["_LOGINREQUEST"]._serialized_start = 133
    _globals["_LOGINREQUEST"]._serialized_end = 197
    _globals["_LOGINRESPONSE"]._serialized_start = 200
    _globals["_LOGINRESPONSE"]._serialized_end = 342
    _globals["_REFRESHTOKENREQUEST"]._serialized_start = 344
    _globals["_REFRESHTOKENREQUEST"]._serialized_end = 402
    _globals["_REFRESHTOKENRESPONSE"]._serialized_start = 404
    _globals["_REFRESHTOKENRESPONSE"]._serialized_end = 511
    _globals["_LOGOUTRESPONSE"]._serialized_start = 513
    _globals["_LOGOUTRESPONSE"]._serialized_end = 572
    _globals["_AUTHSERVICE"]._serialized_start = 575
    _globals["_AUTHSERVICE"]._serialized_end = 786
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: vector_db/v2/vector_db.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "vector_db/v2/vector_db.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cvector_db/v2/vector_db.proto\x12\x0cvector_db.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto"e\n\x06Vector\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06values\x18\x02 \x03(\x02R\x06values\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata"h\n\x0bQueryResult\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05score\x18\x02 \x01(\x02R\x05score\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata"h\n\rUpsertRequest\x12\'\n\x0f\x63ollection_name\x18\x01 \x01(\tR\x0e\x63ollectionName\x12.\n\x07vectors\x18\x02 \x03(\x0b\x32\x14.vector_db.v2.VectorR\x07vectors"b\n\x0eUpsertResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12%\n\x0eupserted_count\x18\x02 \x01(\x05R\rupsertedCount"\xb0\x01\n\x0cQueryRequest\x12\'\n\x0f\x63ollection_name\x18\x01 \x01(\tR\x0e\x63ollectionName\x12!\n\x0cquery_vector\x18\x02 \x03(\x02R\x0bqueryVector\x12\x13\n\x05top_k\x18\x03 \x01(\x05R\x04topK\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter"o\n\rQueryResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x33\n\x07results\x18\x02 \x03(\x0b\x32\x19.vector_db.v2.QueryResultR\x07results2\x9c\x01\n\x0fVectorDBService\x12\x45\n\x06Upsert\x12\x1b.vector_db.v2.UpsertRequest\x1a\x1c.vector_db.v2.UpsertResponse"\x00\x12\x42\n\x05Query\x12\x1a.vector_db.v2.QueryRequest\x1a\x1b.vector_db.v2.QueryResponse"\x00\x42\xb3\x01\n\x10\x63om.vector_db.v2B\rVectorDbProtoP\x01ZCgithub.com/spounge-ai/spounge-protos/gen/go/vector_db/v2;vectordbv2\xa2\x02\x03VXX\xaa\x02\x0bVectorDb.V2\xca\x02\x0bVectorDb\\V2\xe2\x02\x17VectorDb\\V2\\GPBMetadata\xea\x02\x0cVectorDb::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "vector_db.v2.vector_db_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\020com.vector_db.v2B\rVectorDbProtoP\001ZCgithub.com/spounge-ai/spounge-protos/gen/go/vector_db/v2;vectordbv2\242\002\003VXX\252\002\013VectorDb.V2\312\002\013VectorDb\\V2\342\002\027VectorDb\\V2\\GPBMetadata\352\002\014VectorDb::V2"
    _globals["_VECTOR"]._serialized_start = 100
    _globals["_VECTOR"]._serialized_end = 201
    _globals["_QUERYRESULT"]._serialized_start = 203
    _globals["_QUERYRESULT"]._serialized_end = 307
    _globals["_UPSERTREQUEST"]._serialized_start = 309
    _globals["_UPSERTREQUEST"]._serialized_end = 413
    _globals["_UPSERTRESPONSE"]._serialized_start = 415
    _globals["_UPSERTRESPONSE"]._serialized_end = 513
    _globals["_QUERYREQUEST"]._serialized_start = 516
    _globals["_QUERYREQUEST"]._serialized_end = 692
    _globals["_QUERYRESPONSE"]._serialized_start = 694
    _globals["_QUERYRESPONSE"]._serialized_end = 805
    _globals["_VECTORDBSERVICE"]._serialized_start = 808
    _globals["_VECTORDBSERVICE"]._serialized_end = 964
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/auth_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "api/v2/auth_gateway_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!api/v2/auth_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1a\x61uth/v2/auth_service.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto"\\\n\x1e\x41uthGatewayServiceLoginRequest\x12:\n\rlogin_request\x18\x01 \x01(\x0b\x32\x15.auth.v2.LoginRequestR\x0cloginRequest"`\n\x1f\x41uthGatewayServiceLoginResponse\x12=\n\x0elogin_response\x18\x01 \x01(\x0b\x32\x16.auth.v2.LoginResponseR\rloginResponse"y\n%AuthGatewayServiceRefreshTokenRequest\x12P\n\x15refresh_token_request\x18\x01 \x01(\x0b\x32\x1c.auth.v2.RefreshTokenRequestR\x13refreshTokenRequest"}\n&AuthGatewayServiceRefreshTokenResponse\x12S\n\x16refresh_token_response\x18\x01 \x01(\x0b\x32\x1d.auth.v2.RefreshTokenResponseR\x14refreshTokenResponse"O\n\x1f\x41uthGatewayServiceLogoutRequest\x12,\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x05\x65mpty"d\n AuthGatewayServiceLogoutResponse\x12@\n\x0flogout_response\x18\x01 \x01(\x0b\x32\x17.auth.v2.LogoutResponseR\x0elogoutResponse2\x8f\x03\n\x12\x41uthGatewayService\x12s\n\x05Login\x12&.api.v2.AuthGatewayServiceLoginRequest\x1a\'.api.v2.AuthGatewayServiceLoginResponse"\x19\x82\xd3\xe4\x93\x02\x13"\x0e/v2/auth/login:\x01*\x12\x8a\x01\n\x0cRefreshToken\x12-.api.v2.AuthGatewayServiceRefreshTokenRequest\x1a..api.v2.AuthGatewayServiceRefreshTokenResponse"\x1b\x82\xd3\xe4\x93\x02\x15"\x10/v2/auth/refresh:\x01*\x12w\n\x06Logout\x12\'.api.v2.AuthGatewayServiceLogoutRequest\x1a(.api.v2.AuthGatewayServiceLogoutResponse"\x1a\x82\xd3\xe4\x93\x02\x14"\x0f/v2/auth/logout:\x01*B\x98\x01\n\ncom.api.v2B\x17\x41uthGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "api.v2.auth_gateway_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.api.v2B\027AuthGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2"
    _globals["_AUTHGATEWAYSERVICE"].methods_by_name["Login"]._loaded_options = None
    _globals["_AUTHGATEWAYSERVICE"].methods_by_name[
        "Login"
    ]._serialized_options = b'\202\323\344\223\002\023"\016/v2/auth/login:\001*'
    _globals["_AUTHGATEWAYSERVICE"].methods_by_name[
        "RefreshToken"
    ]._loaded_options = None
    _globals["_AUTHGATEWAYSERVICE"].methods_by_name[
        "RefreshToken"
    ]._serialized_options = b'\202\323\344\223\002\025"\020/v2/auth/refresh:\001*'
    _globals["_AUTHGATEWAYSERVICE"].methods_by_name["Logout"]._loaded_options = None
    _globals["_AUTHGATEWAYSERVICE"].methods_by_name[
        "Logout"
    ]._serialized_options = b'\202\323\344\223\002\024"\017/v2/auth/logout:\001*'
    _globals["_AUTHGATEWAYSERVICELOGINREQUEST"]._serialized_start = 132
    _globals["_AUTHGATEWAYSERVICELOGINREQUEST"]._serialized_end = 224
    _globals["_AUTHGATEWAYSERVICELOGINRESPONSE"]._serialized_start = 226
    _globals["_AUTHGATEWAYSERVICELOGINRESPONSE"]._serialized_end = 322
    _globals["_AUTHGATEWAYSERVICEREFRESHTOKENREQUEST"]._serialized_start = 324
    _globals["_AUTHGATEWAYSERVICEREFRESHTOKENREQUEST"]._serialized_end = 445
    _globals["_AUTHGATEWAYSERVICEREFRESHTOKENRESPONSE"]._serialized_start = 447
    _globals["_AUTHGATEWAYSERVICEREFRESHTOKENRESPONSE"]._serialized_end = 572
    _globals["_AUTHGATEWAYSERVICELOGOUTREQUEST"]._serialized_start = 574
    _globals["_AUTHGATEWAYSERVICELOGOUTREQUEST"]._serialized_end = 653
    _globals["_AUTHGATEWAYSERVICELOGOUTRESPONSE"]._serialized_start = 655
    _globals["_AUTHGATEWAYSERVICELOGOUTRESPONSE"]._serialized_end = 755
    _globals["_AUTHGATEWAYSERVICE"]._serialized_start = 758
    _globals["_AUTHGATEWAYSERVICE"]._serialized_end = 1157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/dashboard_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "api/v2/dashboard_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1e\x61pi/v2/dashboard_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x14iam/v2/api_key.proto\x1a\x1biam/v2/managed_secret.proto\x1a\x12user/v2/user.proto\x1a\x1bworkflow/v2/execution.proto\x1a\x1aworkflow/v2/workflow.proto"\x15\n\x13GetDashboardRequest"\xcf\x02\n\x14GetDashboardResponse\x12\x37\n\x0cuser_profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x0buserProfile\x12\x46\n\x10recent_workflows\x18\x02 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x0frecentWorkflows\x12K\n\x11recent_executions\x18\x03 \x03(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\x10recentExecutions\x12)\n\x08\x61pi_keys\x18\x04 \x03(\x0b\x32\x0e.iam.v2.APIKeyR\x07\x61piKeys\x12>\n\x0fmanaged_secrets\x18\x05 \x03(\x0b\x32\x15.iam.v2.ManagedSecretR\x0emanagedSecrets2t\n\x10\x44\x61shboardService\x12`\n\x0cGetDashboard\x12\x1b.api.v2.GetDashboardRequest\x1a\x1c.api.v2.GetDashboardResponse"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v2/dashboardB\x96\x01\n\ncom.api.v2B\x15\x44\x61shboardServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "api.v2.dashboard_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.api.v2B\025DashboardServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2"
    _globals["_DASHBOARDSERVICE"].methods_by_name["GetDashboard"]._loaded_options = None
    _globals["_DASHBOARDSERVICE"].methods_by_name[
        "GetDashboard"
    ]._serialized_options = b"\202\323\344\223\002\017\022\r/v2/dashboard"
    _globals["_GETDASHBOARDREQUEST"]._serialized_start = 200
    _globals["_GETDASHBOARDREQUEST"]._serialized_end = 221
    _globals["_GETDASHBOARDRESPONSE"]._serialized_start = 224
    _globals["_GETDASHBOARDRESPONSE"]._serialized_end = 559
    _globals["_DASHBOARDSERVICE"]._serialized_start = 561
    _globals["_DASHBOARDSERVICE"]._serialized_end = 677
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from vector_db.v2 import vector_db_pb2 as vector__db_dot_v2_dot_vector__db__pb2


class VectorDBServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Upsert = channel.unary_unary(
            "/vector_db.v2.VectorDBService/Upsert",
            request_serializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertRequest.SerializeToString,
            response_deserializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertResponse.FromString,
            _registered_method=True,
        )
        self.Query = channel.unary_unary(
            "/vector_db.v2.VectorDBService/Query",
            request_serializer=vector__db_dot_v2_dot_vector__db__pb2.QueryRequest.SerializeToString,
            response_deserializer=vector__db_dot_v2_dot_vector__db__pb2.QueryResponse.FromString,
            _registered_method=True,
        )


class VectorDBServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Upsert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Query(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_VectorDBServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Upsert": grpc.unary_unary_rpc_method_handler(
            servicer.Upsert,
            request_deserializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertRequest.FromString,
            response_serializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertResponse.SerializeToString,
        ),
        "Query": grpc.unary_unary_rpc_method_handler(
            servicer.Query,
            request_deserializer=vector__db_dot_v2_dot_vector__db__pb2.QueryRequest.FromString,
            response_serializer=vector__db_dot_v2_dot_vector__db__pb2.QueryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "vector_db.v2.VectorDBService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "vector_db.v2.VectorDBService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class VectorDBService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Upsert(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/vector_db.v2.VectorDBService/Upsert",
            vector__db_dot_v2_dot_vector__db__pb2.UpsertRequest.SerializeToString,
            vector__db_dot_v2_dot_vector__db__pb2.UpsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Query(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/vector_db.v2.VectorDBService/Query",
            vector__db_dot_v2_dot_vector__db__pb2.QueryRequest.SerializeToString,
            vector__db_dot_v2_dot_vector__db__pb2.QueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/stream_operations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/stream_operations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.polykey.v2 import common_pb2 as polykey_dot_v2_dot_common__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"polykey/v2/stream_operations.proto\x12\npolykey.v2\x1a\x17polykey/v2/common.proto\x1a\"polykey/v2/single_operations.proto\"\x8c\x02\n\x14StreamGetKeysRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x03 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\x12(\n\rskip_metadata\x18\x05 \x01(\x08H\x00R\x0cskipMetadata\x88\x01\x01\x42\x10\n\x0e_skip_metadata\"Q\n\x17StreamCreateKeysRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.CreateKeyRequestR\x07request\"Q\n\x17StreamRotateKeysRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RotateKeyRequestR\x07request\"Q\n\x17StreamRevokeKeysRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RevokeKeyRequestR\x07request\"`\n\x1eStreamUpdateKeyMetadataRequest\x12>\n\x07request\x18\x01 \x01(\x0b\x32$.polykey.v2.UpdateKeyMetadataRequestR\x07request\"Z\n\x1bStreamGetKeyMetadataRequest\x12;\n\x07request\x18\x01 \x01(\x0b\x32!.polykey.v2.GetKeyMetadataRequestR\x07request\"\xb1\x01\n\x15StreamGetKeysResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x36\n\x07success\x18\x02 \x01(\x0b\x32\x1a.polykey.v2.GetKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rror\x12\'\n\x0fsequence_number\x18\x04 \x01(\x05R\x0esequenceNumberB\x08\n\x06result\"\xa2\x01\n\x18StreamCreateKeysResponse\x12)\n\x10request_sequence\x18\x01 \x01(\x05R\x0frequestSequence\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.CreateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\x8e\x01\n\x18StreamRotateKeysResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.RotateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"o\n\x18StreamRevokeKeysResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"v\n\x1fStreamUpdateKeyMetadataResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\x97\x01\n\x1cStreamGetKeyMetadataResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12>\n\x07success\x18\x02 \x01(\x0b\x32\".polykey.v2.GetKeyMetadataResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06resultB\xb1\x01\n\x0e\x63om.polykey.v2B\x15StreamOperationsProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.stream_operations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\025StreamOperationsProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_STREAMGETKEYSREQUEST']._serialized_start=112
  _globals['_STREAMGETKEYSREQUEST']._serialized_end=380
  _globals['_STREAMCREATEKEYSREQUEST']._serialized_start=382
  _globals['_STREAMCREATEKEYSREQUEST']._serialized_end=463
  _globals['_STREAMROTATEKEYSREQUEST']._serialized_start=465
  _globals['_STREAMROTATEKEYSREQUEST']._serialized_end=546
  _globals['_STREAMREVOKEKEYSREQUEST']._serialized_start=548
  _globals['_STREAMREVOKEKEYSREQUEST']._serialized_end=629
  _globals['_STREAMUPDATEKEYMETADATAREQUEST']._serialized_start=631
  _globals['_STREAMUPDATEKEYMETADATAREQUEST']._serialized_end=727
  _globals['_STREAMGETKEYMETADATAREQUEST']._serialized_start=729
  _globals['_STREAMGETKEYMETADATAREQUEST']._serialized_end=819
  _globals['_STREAMGETKEYSRESPONSE']._serialized_start=822
  _globals['_STREAMGETKEYSRESPONSE']._serialized_end=999
  _globals['_STREAMCREATEKEYSRESPONSE']._serialized_start=1002
  _globals['_STREAMCREATEKEYSRESPONSE']._serialized_end=1164
  _globals['_STREAMROTATEKEYSRESPONSE']._serialized_start=1167
  _globals['_STREAMROTATEKEYSRESPONSE']._serialized_end=1309
  _globals['_STREAMREVOKEKEYSRESPONSE']._serialized_start=1311
  _globals['_STREAMREVOKEKEYSRESPONSE']._serialized_end=1422
  _globals['_STREAMUPDATEKEYMETADATARESPONSE']._serialized_start=1424
  _globals['_STREAMUPDATEKEYMETADATARESPONSE']._serialized_end=1542
  _globals['_STREAMGETKEYMETADATARESPONSE']._serialized_start=1545
  _globals['_STREAMGETKEYMETADATARESPONSE']._serialized_end=1696
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from api.v2 import (
    workflow_gateway_service_pb2 as api_dot_v2_dot_workflow__gateway__service__pb2,
)


class WorkflowGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWorkflow = channel.unary_unary(
            "/api.v2.WorkflowGatewayService/CreateWorkflow",
            request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowResponse.FromString,
            _registered_method=True,
        )
        self.GetWorkflow = channel.unary_unary(
            "/api.v2.WorkflowGatewayService/GetWorkflow",
            request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowResponse.FromString,
            _registered_method=True,
        )
        self.ListWorkflows = channel.unary_unary(
            "/api.v2.WorkflowGatewayService/ListWorkflows",
            request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsResponse.FromString,
            _registered_method=True,
        )
        self.StartExecution = channel.unary_unary(
            "/api.v2.WorkflowGatewayService/StartExecution",
            request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionResponse.FromString,
            _registered_method=True,
        )
        self.GetExecution = channel.unary_unary(
            "/api.v2.WorkflowGatewayService/GetExecution",
            request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionResponse.FromString,
            _registered_method=True,
        )


class WorkflowGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListWorkflows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StartExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WorkflowGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateWorkflow": grpc.unary_unary_rpc_method_handler(
            servicer.CreateWorkflow,
            request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowRequest.FromString,
            response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowResponse.SerializeToString,
        ),
        "GetWorkflow": grpc.unary_unary_rpc_method_handler(
            servicer.GetWorkflow,
            request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowRequest.FromString,
            response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowResponse.SerializeToString,
        ),
        "ListWorkflows": grpc.unary_unary_rpc_method_handler(
            servicer.ListWorkflows,
            request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsRequest.FromString,
            response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsResponse.SerializeToString,
        ),
        "StartExecution": grpc.unary_unary_rpc_method_handler(
            servicer.StartExecution,
            request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionRequest.FromString,
            response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionResponse.SerializeToString,
        ),
        "GetExecution": grpc.unary_unary_rpc_method_handler(
            servicer.GetExecution,
            request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionRequest.FromString,
            response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v2.WorkflowGatewayService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "api.v2.WorkflowGatewayService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class WorkflowGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateWorkflow(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.WorkflowGatewayService/CreateWorkflow",
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetWorkflow(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.WorkflowGatewayService/GetWorkflow",
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListWorkflows(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.WorkflowGatewayService/ListWorkflows",
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StartExecution(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.WorkflowGatewayService/StartExecution",
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetExecution(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.WorkflowGatewayService/GetExecution",
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/workflow_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    "",
    "api/v2/workflow_gateway_service.proto",
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%api/v2/workflow_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a#workflow/v2/execution_service.proto\x1a"workflow/v2/workflow_service.proto"\x89\x01\n+WorkflowGatewayServiceCreateWorkflowRequest\x12Z\n\x17\x63reate_workflow_request\x18\x01 \x01(\x0b\x32".workflow.v2.CreateWorkflowRequestR\x15\x63reateWorkflowRequest"\x8d\x01\n,WorkflowGatewayServiceCreateWorkflowResponse\x12]\n\x18\x63reate_workflow_response\x18\x01 \x01(\x0b\x32#.workflow.v2.CreateWorkflowResponseR\x16\x63reateWorkflowResponse"}\n(WorkflowGatewayServiceGetWorkflowRequest\x12Q\n\x14get_workflow_request\x18\x01 \x01(\x0b\x32\x1f.workflow.v2.GetWorkflowRequestR\x12getWorkflowRequest"\x81\x01\n)WorkflowGatewayServiceGetWorkflowResponse\x12T\n\x15get_workflow_response\x18\x01 \x01(\x0b\x32 .workflow.v2.GetWorkflowResponseR\x13getWorkflowResponse"\x85\x01\n*WorkflowGatewayServiceListWorkflowsRequest\x12W\n\x16list_workflows_request\x18\x01 \x01(\x0b\x32!.workflow.v2.ListWorkflowsRequestR\x14listWorkflowsRequest"\x89\x01\n+WorkflowGatewayServiceListWorkflowsResponse\x12Z\n\x17list_workflows_response\x18\x01 \x01(\x0b\x32".workflow.v2.ListWorkflowsResponseR\x15listWorkflowsResponse"\x89\x01\n+WorkflowGatewayServiceStartExecutionRequest\x12Z\n\x17start_execution_request\x18\x01 \x01(\x0b\x32".workflow.v2.StartExecutionRequestR\x15startExecutionRequest"\x8d\x01\n,WorkflowGatewayServiceStartExecutionResponse\x12]\n\x18start_execution_response\x18\x01 \x01(\x0b\x32#.workflow.v2.StartExecutionResponseR\x16startExecutionResponse"\x81\x01\n)WorkflowGatewayServiceGetExecutionRequest\x12T\n\x15get_execution_request\x18\x01 \x01(\x0b\x32 .workflow.v2.GetExecutionRequestR\x13getExecutionRequest"\x85\x01\n*WorkflowGatewayServiceGetExecutionResponse\x12W\n\x16get_execution_response\x18\x01 \x01(\x0b\x32!.workflow.v2.GetExecutionResponseR\x14getExecutionResponse2\xec\x06\n\x16WorkflowGatewayService\x12\x95\x01\n\x0e\x43reateWorkflow\x12\x33.api.v2.WorkflowGatewayServiceCreateWorkflowRequest\x1a\x34.api.v2.WorkflowGatewayServiceCreateWorkflowResponse"\x18\x82\xd3\xe4\x93\x02\x12"\r/v2/workflows:\x01*\x12\xac\x01\n\x0bGetWorkflow\x12\x30.api.v2.WorkflowGatewayServiceGetWorkflowRequest\x1a\x31.api.v2.WorkflowGatewayServiceGetWorkflowResponse"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v2/workflows/{get_workflow_request.workflow_id}\x12\x8f\x01\n\rListWorkflows\x12\x32.api.v2.WorkflowGatewayServiceListWorkflowsRequest\x1a\x33.api.v2.WorkflowGatewayServiceListWorkflowsResponse"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v2/workflows\x12\xc3\x01\n\x0eStartExecution\x12\x33.api.v2.WorkflowGatewayServiceStartExecutionRequest\x1a\x34.api.v2.WorkflowGatewayServiceStartExecutionResponse"F\x82\xd3\xe4\x93\x02@";/v2/workflows/{start_execution_request.workflow_id}/execute:\x01*\x12\xb2\x01\n\x0cGetExecution\x12\x31.api.v2.WorkflowGatewayServiceGetExecutionRequest\x1a\x32.api.v2.WorkflowGatewayServiceGetExecutionResponse";\x82\xd3\xe4\x93\x02\x35\x12\x33/v2/executions/{get_execution_request.execution_id}B\x9c\x01\n\ncom.api.v2B\x1bWorkflowGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "api.v2.workflow_gateway_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.api.v2B\033WorkflowGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2"
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "CreateWorkflow"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "CreateWorkflow"
    ]._serialized_options = b'\202\323\344\223\002\022"\r/v2/workflows:\001*'
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetWorkflow"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetWorkflow"
    ]._serialized_options = (
        b"\202\323\344\223\0022\0220/v2/workflows/{get_workflow_request.workflow_id}"
    )
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "ListWorkflows"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "ListWorkflows"
    ]._serialized_options = b"\202\323\344\223\002\017\022\r/v2/workflows"
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "StartExecution"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "StartExecution"
    ]._serialized_options = b'\202\323\344\223\002@";/v2/workflows/{start_execution_request.workflow_id}/execute:\001*'
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetExecution"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetExecution"
    ]._serialized_options = (
        b"\202\323\344\223\0025\0223/v2/executions/{get_execution_request.execution_id}"
    )
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWREQUEST"]._serialized_start = 153
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWREQUEST"]._serialized_end = 290
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWRESPONSE"]._serialized_start = 293
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWRESPONSE"]._serialized_end = 434
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWREQUEST"]._serialized_start = 436
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWREQUEST"]._serialized_end = 561
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWRESPONSE"]._serialized_start = 564
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWRESPONSE"]._serialized_end = 693
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSREQUEST"]._serialized_start = 696
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSREQUEST"]._serialized_end = 829
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSRESPONSE"]._serialized_start = 832
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSRESPONSE"]._serialized_end = 969
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONREQUEST"]._serialized_start = 972
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONREQUEST"]._serialized_end = 1109
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONRESPONSE"]._serialized_start = 1112
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONRESPONSE"]._serialized_end = 1253
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONREQUEST"]._serialized_start = 1256
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONREQUEST"]._serialized_end = 1385
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONRESPONSE"]._serialized_start = 1388
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONRESPONSE"]._serialized_end = 1521
    _globals["_WORKFLOWGATEWAYSERVICE"]._serialized_start = 1524
    _globals["_WORKFLOWGATEWAYSERVICE"]._serialized_end = 2400
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from auth.v2 import auth_service_pb2 as auth_dot_v2_dot_auth__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AuthServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
            "/auth.v2.AuthService/Login",
            request_serializer=auth_dot_v2_dot_auth__service__pb2.LoginRequest.SerializeToString,
            response_deserializer=auth_dot_v2_dot_auth__service__pb2.LoginResponse.FromString,
            _registered_method=True,
        )
        self.RefreshToken = channel.unary_unary(
            "/auth.v2.AuthService/RefreshToken",
            request_serializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenRequest.SerializeToString,
            response_deserializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenResponse.FromString,
            _registered_method=True,
        )
        self.Logout = channel.unary_unary(
            "/auth.v2.AuthService/Logout",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=auth_dot_v2_dot_auth__service__pb2.LogoutResponse.FromString,
            _registered_method=True,
        )


class AuthServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Logout(self, request, context):
        """Logout invalidates the user's session based on the provided auth token."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Login": grpc.unary_unary_rpc_method_handler(
            servicer.Login,
            request_deserializer=auth_dot_v2_dot_auth__service__pb2.LoginRequest.FromString,
            response_serializer=auth_dot_v2_dot_auth__service__pb2.LoginResponse.SerializeToString,
        ),
        "RefreshToken": grpc.unary_unary_rpc_method_handler(
            servicer.RefreshToken,
            request_deserializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenRequest.FromString,
            response_serializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenResponse.SerializeToString,
        ),
        "Logout": grpc.unary_unary_rpc_method_handler(
            servicer.Logout,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=auth_dot_v2_dot_auth__service__pb2.LogoutResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "auth.v2.AuthService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("auth.v2.AuthService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class AuthService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Login(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/auth.v2.AuthService/Login",
            auth_dot_v2_dot_auth__service__pb2.LoginRequest.SerializeToString,
            auth_dot_v2_dot_auth__service__pb2.LoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def RefreshToken(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/auth.v2.AuthService/RefreshToken",
            auth_dot_v2_dot_auth__service__pb2.RefreshTokenRequest.SerializeToString,
            auth_dot_v2_dot_auth__service__pb2.RefreshTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Logout(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/auth.v2.AuthService/Logout",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            auth_dot_v2_dot_auth__service__pb2.LogoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Auto-generated __init__.py
from . import context
from . import code_pb2, code_pb2_grpc, error_details_pb2, error_details_pb2_grpc, status_pb2, status_pb2_grpc

__all__ = ["code_pb2", "code_pb2_grpc", "context", "error_details_pb2", "error_details_pb2_grpc", "status_pb2", "status_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/expr/v1beta1/decl.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "google/api/expr/v1beta1/decl.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"google/api/expr/v1beta1/decl.proto\x12\x17google.api.expr.v1beta1\x1a"google/api/expr/v1beta1/expr.proto"\xc5\x01\n\x04\x44\x65\x63l\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x10\n\x03\x64oc\x18\x03 \x01(\tR\x03\x64oc\x12:\n\x05ident\x18\x04 \x01(\x0b\x32".google.api.expr.v1beta1.IdentDeclH\x00R\x05ident\x12\x43\n\x08\x66unction\x18\x05 \x01(\x0b\x32%.google.api.expr.v1beta1.FunctionDeclH\x00R\x08\x66unctionB\x06\n\x04kind"r\n\x08\x44\x65\x63lType\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x42\n\x0btype_params\x18\x04 \x03(\x0b\x32!.google.api.expr.v1beta1.DeclTypeR\ntypeParams"w\n\tIdentDecl\x12\x35\n\x04type\x18\x03 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclTypeR\x04type\x12\x33\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x05value"\xb7\x01\n\x0c\x46unctionDecl\x12\x36\n\x04\x61rgs\x18\x01 \x03(\x0b\x32".google.api.expr.v1beta1.IdentDeclR\x04\x61rgs\x12\x42\n\x0breturn_type\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclTypeR\nreturnType\x12+\n\x11receiver_function\x18\x03 \x01(\x08R\x10receiverFunctionB\xe7\x01\n\x1b\x63om.google.api.expr.v1beta1B\tDeclProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x17Google.Api.Expr.V1beta1\xca\x02\x17Google\\Api\\Expr\\V1beta1\xe2\x02#Google\\Api\\Expr\\V1beta1\\GPBMetadata\xea\x02\x1aGoogle::Api::Expr::V1beta1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.api.expr.v1beta1.decl_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\033com.google.api.expr.v1beta1B\tDeclProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001\242\002\003GAE\252\002\027Google.Api.Expr.V1beta1\312\002\027Google\\Api\\Expr\\V1beta1\342\002#Google\\Api\\Expr\\V1beta1\\GPBMetadata\352\002\032Google::Api::Expr::V1beta1"
    _globals["_DECL"]._serialized_start = 100
    _globals["_DECL"]._serialized_end = 297
    _globals["_DECLTYPE"]._serialized_start = 299
    _globals["_DECLTYPE"]._serialized_end = 413
    _globals["_IDENTDECL"]._serialized_start = 415
    _globals["_IDENTDECL"]._serialized_end = 534
    _globals["_FUNCTIONDECL"]._serialized_start = 537
    _globals["_FUNCTIONDECL"]._serialized_end = 720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/localized_text.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "google/type/localized_text.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n google/type/localized_text.proto\x12\x0bgoogle.type"H\n\rLocalizedText\x12\x12\n\x04text\x18\x01 \x01(\tR\x04text\x12#\n\rlanguage_code\x18\x02 \x01(\tR\x0clanguageCodeB\xbf\x01\n\x0f\x63om.google.typeB\x12LocalizedTextProtoP\x01ZHgoogle.golang.org/genproto/googleapis/type/localized_text;localized_text\xf8\x01\x01\xa2\x02\x03GTX\xaa\x02\x0bGoogle.Type\xca\x02\x0bGoogle\\Type\xe2\x02\x17Google\\Type\\GPBMetadata\xea\x02\x0cGoogle::Typeb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.type.localized_text_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\017com.google.typeB\022LocalizedTextProtoP\001ZHgoogle.golang.org/genproto/googleapis/type/localized_text;localized_text\370\001\001\242\002\003GTX\252\002\013Google.Type\312\002\013Google\\Type\342\002\027Google\\Type\\GPBMetadata\352\002\014Google::Type"
    _globals["_LOCALIZEDTEXT"]._serialized_start = 49
    _globals["_LOCALIZEDTEXT"]._serialized_end = 121
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/execution_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "workflow/v2/execution_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#workflow/v2/execution_service.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bworkflow/v2/execution.proto"\xbf\x01\n\x15StartExecutionRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12.\n\x10workflow_version\x18\x02 \x01(\x05H\x00R\x0fworkflowVersion\x88\x01\x01\x12@\n\x0finitial_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0einitialContextB\x13\n\x11_workflow_version"V\n\x16StartExecutionResponse\x12<\n\texecution\x18\x01 \x01(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\texecution"8\n\x13GetExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId"T\n\x14GetExecutionResponse\x12<\n\texecution\x18\x01 \x01(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\texecution"u\n\x15ListExecutionsRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationParamsR\npagination"\x95\x01\n\x16ListExecutionsResponse\x12>\n\nexecutions\x18\x01 \x03(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\nexecutions\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationResultR\npagination";\n\x16\x43\x61ncelExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId"D\n\x17\x43\x61ncelExecutionResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status";\n\x16StreamExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId"W\n\x17StreamExecutionResponse\x12<\n\x06update\x18\x01 \x01(\x0b\x32$.workflow.v2.WorkflowExecutionUpdateR\x06update2\xe5\x03\n\x10\x45xecutionService\x12[\n\x0eStartExecution\x12".workflow.v2.StartExecutionRequest\x1a#.workflow.v2.StartExecutionResponse"\x00\x12U\n\x0cGetExecution\x12 .workflow.v2.GetExecutionRequest\x1a!.workflow.v2.GetExecutionResponse"\x00\x12[\n\x0eListExecutions\x12".workflow.v2.ListExecutionsRequest\x1a#.workflow.v2.ListExecutionsResponse"\x00\x12^\n\x0f\x43\x61ncelExecution\x12#.workflow.v2.CancelExecutionRequest\x1a$.workflow.v2.CancelExecutionResponse"\x00\x12`\n\x0fStreamExecution\x12#.workflow.v2.StreamExecutionRequest\x1a$.workflow.v2.StreamExecutionResponse"\x00\x30\x01\x42\xb9\x01\n\x0f\x63om.workflow.v2B\x15\x45xecutionServiceProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "workflow.v2.execution_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\017com.workflow.v2B\025ExecutionServiceProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2"
    _globals["_STARTEXECUTIONREQUEST"]._serialized_start = 136
    _globals["_STARTEXECUTIONREQUEST"]._serialized_end = 327
    _globals["_STARTEXECUTIONRESPONSE"]._serialized_start = 329
    _globals["_STARTEXECUTIONRESPONSE"]._serialized_end = 415
    _globals["_GETEXECUTIONREQUEST"]._serialized_start = 417
    _globals["_GETEXECUTIONREQUEST"]._serialized_end = 473
    _globals["_GETEXECUTIONRESPONSE"]._serialized_start = 475
    _globals["_GETEXECUTIONRESPONSE"]._serialized_end = 559
    _globals["_LISTEXECUTIONSREQUEST"]._serialized_start = 561
    _globals["_LISTEXECUTIONSREQUEST"]._serialized_end = 678
    _globals["_LISTEXECUTIONSRESPONSE"]._serialized_start = 681
    _globals["_LISTEXECUTIONSRESPONSE"]._serialized_end = 830
    _globals["_CANCELEXECUTIONREQUEST"]._serialized_start = 832
    _globals["_CANCELEXECUTIONREQUEST"]._serialized_end = 891
    _globals["_CANCELEXECUTIONRESPONSE"]._serialized_start = 893
    _globals["_CANCELEXECUTIONRESPONSE"]._serialized_end = 961
    _globals["_STREAMEXECUTIONREQUEST"]._serialized_start = 963
    _globals["_STREAMEXECUTIONREQUEST"]._serialized_end = 1022
    _globals["_STREAMEXECUTIONRESPONSE"]._serialized_start = 1024
    _globals["_STREAMEXECUTIONRESPONSE"]._serialized_end = 1111
    _globals["_EXECUTIONSERVICE"]._serialized_start = 1114
    _globals["_EXECUTIONSERVICE"]._serialized_end = 1599
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from nodus.v1.mcp.v1 import (
    connection_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2,
)
from nodus.v1.nodes.v1 import (
    execution_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2,
)
from nodus.v1.service.v1 import (
    service_pb2 as nodus_dot_v1_dot_service_dot_v1_dot_service__pb2,
)


class NodusServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExecuteNode = channel.unary_unary(
            "/nodus.v1.service.v1.NodusService/ExecuteNode",
            request_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeRequest.SerializeToString,
            response_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeResponse.FromString,
            _registered_method=True,
        )
        self.ExecuteNodeStream = channel.unary_stream(
            "/nodus.v1.service.v1.NodusService/ExecuteNodeStream",
            request_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamRequest.SerializeToString,
            response_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamResponse.FromString,
            _registered_method=True,
        )
        self.RegisterMCPServer = channel.unary_unary(
            "/nodus.v1.service.v1.NodusService/RegisterMCPServer",
            request_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerRequest.SerializeToString,
            response_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerResponse.FromString,
            _registered_method=True,
        )
        self.ListMCPServers = channel.unary_unary(
            "/nodus.v1.service.v1.NodusService/ListMCPServers",
            request_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersRequest.SerializeToString,
            response_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersResponse.FromString,
            _registered_method=True,
        )
        self.QueryMCPTools = channel.unary_unary(
            "/nodus.v1.service.v1.NodusService/QueryMCPTools",
            request_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsRequest.SerializeToString,
            response_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsResponse.FromString,
            _registered_method=True,
        )
        self.CheckHealth = channel.unary_unary(
            "/nodus.v1.service.v1.NodusService/CheckHealth",
            request_serializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthRequest.SerializeToString,
            response_deserializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthResponse.FromString,
            _registered_method=True,
        )


class NodusServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExecuteNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExecuteNodeStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RegisterMCPServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListMCPServers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QueryMCPTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CheckHealth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_NodusServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ExecuteNode": grpc.unary_unary_rpc_method_handler(
            servicer.ExecuteNode,
            request_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeRequest.FromString,
            response_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeResponse.SerializeToString,
        ),
        "ExecuteNodeStream": grpc.unary_stream_rpc_method_handler(
            servicer.ExecuteNodeStream,
            request_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamRequest.FromString,
            response_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamResponse.SerializeToString,
        ),
        "RegisterMCPServer": grpc.unary_unary_rpc_method_handler(
            servicer.RegisterMCPServer,
            request_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerRequest.FromString,
            response_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerResponse.SerializeToString,
        ),
        "ListMCPServers": grpc.unary_unary_rpc_method_handler(
            servicer.ListMCPServers,
            request_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersRequest.FromString,
            response_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersResponse.SerializeToString,
        ),
        "QueryMCPTools": grpc.unary_unary_rpc_method_handler(
            servicer.QueryMCPTools,
            request_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsRequest.FromString,
            response_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsResponse.SerializeToString,
        ),
        "CheckHealth": grpc.unary_unary_rpc_method_handler(
            servicer.CheckHealth,
            request_deserializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthRequest.FromString,
            response_serializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "nodus.v1.service.v1.NodusService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "nodus.v1.service.v1.NodusService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class NodusService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExecuteNode(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/nodus.v1.service.v1.NodusService/ExecuteNode",
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeRequest.SerializeToString,
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ExecuteNodeStream(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/nodus.v1.service.v1.NodusService/ExecuteNodeStream",
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamRequest.SerializeToString,
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def RegisterMCPServer(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/nodus.v1.service.v1.NodusService/RegisterMCPServer",
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerRequest.SerializeToString,
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListMCPServers(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/nodus.v1.service.v1.NodusService/ListMCPServers",
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersRequest.SerializeToString,
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def QueryMCPTools(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/nodus.v1.service.v1.NodusService/QueryMCPTools",
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsRequest.SerializeToString,
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def CheckHealth(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/nodus.v1.service.v1.NodusService/CheckHealth",
            nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthRequest.SerializeToString,
            nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from workflow.v2 import (
    workflow_service_pb2 as workflow_dot_v2_dot_workflow__service__pb2,
)


class WorkflowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWorkflow = channel.unary_unary(
            "/workflow.v2.WorkflowService/CreateWorkflow",
            request_serializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowResponse.FromString,
            _registered_method=True,
        )
        self.GetWorkflow = channel.unary_unary(
            "/workflow.v2.WorkflowService/GetWorkflow",
            request_serializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowResponse.FromString,
            _registered_method=True,
        )
        self.UpdateWorkflow = channel.unary_unary(
            "/workflow.v2.WorkflowService/UpdateWorkflow",
            request_serializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowResponse.FromString,
            _registered_method=True,
        )
        self.DeleteWorkflow = channel.unary_unary(
            "/workflow.v2.WorkflowService/DeleteWorkflow",
            request_serializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowResponse.FromString,
            _registered_method=True,
        )
        self.ListWorkflows = channel.unary_unary(
            "/workflow.v2.WorkflowService/ListWorkflows",
            request_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsResponse.FromString,
            _registered_method=True,
        )
        self.ListWorkflowVersions = channel.unary_unary(
            "/workflow.v2.WorkflowService/ListWorkflowVersions",
            request_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsRequest.SerializeToString,
            response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsResponse.FromString,
            _registered_method=True,
        )


class WorkflowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListWorkflows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListWorkflowVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WorkflowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateWorkflow": grpc.unary_unary_rpc_method_handler(
            servicer.CreateWorkflow,
            request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowRequest.FromString,
            response_serializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowResponse.SerializeToString,
        ),
        "GetWorkflow": grpc.unary_unary_rpc_method_handler(
            servicer.GetWorkflow,
            request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowRequest.FromString,
            response_serializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowResponse.SerializeToString,
        ),
        "UpdateWorkflow": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateWorkflow,
            request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowRequest.FromString,
            response_serializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowResponse.SerializeToString,
        ),
        "DeleteWorkflow": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteWorkflow,
            request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowRequest.FromString,
            response_serializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowResponse.SerializeToString,
        ),
        "ListWorkflows": grpc.unary_unary_rpc_method_handler(
            servicer.ListWorkflows,
            request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsRequest.FromString,
            response_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsResponse.SerializeToString,
        ),
        "ListWorkflowVersions": grpc.unary_unary_rpc_method_handler(
            servicer.ListWorkflowVersions,
            request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsRequest.FromString,
            response_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "workflow.v2.WorkflowService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "workflow.v2.WorkflowService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class WorkflowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateWorkflow(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.WorkflowService/CreateWorkflow",
            workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetWorkflow(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.WorkflowService/GetWorkflow",
            workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def UpdateWorkflow(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.WorkflowService/UpdateWorkflow",
            workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def DeleteWorkflow(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.WorkflowService/DeleteWorkflow",
            workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListWorkflows(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.WorkflowService/ListWorkflows",
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListWorkflowVersions(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/workflow.v2.WorkflowService/ListWorkflowVersions",
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from api.v2 import (
    user_gateway_service_pb2 as api_dot_v2_dot_user__gateway__service__pb2,
)


class UserGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserProfile = channel.unary_unary(
            "/api.v2.UserGatewayService/GetUserProfile",
            request_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.FromString,
            _registered_method=True,
        )
        self.UpdateUserProfile = channel.unary_unary(
            "/api.v2.UserGatewayService/UpdateUserProfile",
            request_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.FromString,
            _registered_method=True,
        )


class UserGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserProfile,
            request_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.FromString,
            response_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.SerializeToString,
        ),
        "UpdateUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUserProfile,
            request_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.FromString,
            response_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v2.UserGatewayService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "api.v2.UserGatewayService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class UserGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.UserGatewayService/GetUserProfile",
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.SerializeToString,
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def UpdateUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.UserGatewayService/UpdateUserProfile",
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.SerializeToString,
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Auto-generated __init__.py
from . import checked_pb2, checked_pb2_grpc, eval_pb2, eval_pb2_grpc, explain_pb2, explain_pb2_grpc, syntax_pb2, syntax_pb2_grpc, value_pb2, value_pb2_grpc

__all__ = ["checked_pb2", "checked_pb2_grpc", "eval_pb2", "eval_pb2_grpc", "explain_pb2", "explain_pb2_grpc", "syntax_pb2", "syntax_pb2_grpc", "value_pb2", "value_pb2_grpc"]
